/*:
![Design Patterns](patterns-01.png)

# Behavioral Design Patterns

Behavioral design patterns are concerned with algorithms and the assignment of responsibilities between objects.

## Chain of Responsibility ★☆☆

Lets you pass requests along a chain of handlers. Upon receiving a request, each handler decides either to process the request or to pass it to the next handler in the chain.

* [Main article →](https://refactoring.guru/design-patterns/chain-of-responsibility)
* [Conceptual example](Chain%20of%20Responsibility%20Conceptual%20Example)
* [Real-world example](Chain%20of%20Responsibility%20Real%20World%20Example)

## Command ★★★

Turns a request into a stand-alone object that contains all information about the request. This transformation lets you pass requests as a method arguments, delay or queue a request's execution, and support undoable operations.

* [Main article →](https://refactoring.guru/design-patterns/command)
* [Conceptual example](Command%20Conceptual%20Example)
* [Real-world example](Command%20Real%20World%20Example)

## Iterator ★★★

Lets you traverse elements of a collection without exposing its underlying representation (list, stack, tree, etc.).

* [Main article →](https://refactoring.guru/design-patterns/iterator)
* [Conceptual example](Iterator%20Conceptual%20Example)
* [Real-world example](Iterator%20Real%20World%20Example)

## Mediator ★★☆

Lets you reduce chaotic dependencies between objects. The pattern restricts direct communications between the objects and forces them to collaborate only via a mediator object.

* [Main article →](https://refactoring.guru/design-patterns/mediator)
* [Conceptual example](Mediator%20Conceptual%20Example)
* [Real-world example](Mediator%20Real%20World%20Example)

## Memento ★☆☆

Lets you save and restore the previous state of an object without revealing the details of its implementation.

* [Main article →](https://refactoring.guru/design-patterns/memento)
* [Conceptual example](Memento%20Conceptual%20Example)
* [Real-world example](Memento%20Real%20World%20Example)

## Observer ★★★

Lets you define a subscription mechanism to notify multiple objects about any events that happen to the object they're observing.

* [Main article →](https://refactoring.guru/design-patterns/observer)
* [Conceptual example](Observer%20Conceptual%20Example)
* [Real-world example](Observer%20Real%20World%20Example)

## State ★★☆

Lets an object alter its behavior when its internal state changes. It appears as if the object changed its class.

* [Main article →](https://refactoring.guru/design-patterns/state)
* [Conceptual example](State%20Conceptual%20Example)
* [Real-world example](State%20Real%20World%20Example)

## Strategy ★★★

Lets you define a family of algorithms, put each of them into a separate class, and make their objects interchangeable.

* [Main article →](https://refactoring.guru/design-patterns/strategy)
* [Conceptual example](Strategy%20Conceptual%20Example)
* [Real-world example](Strategy%20Real%20World%20Example)

## Template Method ★★☆

Defines the skeleton of an algorithm in the superclass but lets subclasses override specific steps of the algorithm without changing its structure.

* [Main article →](https://refactoring.guru/design-patterns/template-method)
* [Conceptual example](Template%20Method%20Conceptual%20Example)
* [Real-world example](Template%20Method%20Real%20World%20Example)

## Visitor ★☆☆

Lets you separate algorithms from the objects on which they operate.

* [Main article →](https://refactoring.guru/design-patterns/visitor)
* [Conceptual example](Visitor%20Conceptual%20Example)
* [Real-world example](Visitor%20Real%20World%20Example)
 */
